You are viewing a plain text version of this content. The canonical link for it is here.
Posted to c-commits@axis.apache.org by da...@apache.org on 2011/06/01 11:58:32 UTC

svn commit: r1130076 - in /axis/axis2/c/core/trunk/samples/client/ntlm: ntlm_post.c ntlm_post_with_check.c

Author: damitha
Date: Wed Jun  1 09:58:31 2011
New Revision: 1130076

URL: http://svn.apache.org/viewvc?rev=1130076&view=rev
Log:
Update samples

Modified:
    axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post.c
    axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post_with_check.c

Modified: axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post.c
URL: http://svn.apache.org/viewvc/axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post.c?rev=1130076&r1=1130075&r2=1130076&view=diff
==============================================================================
--- axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post.c (original)
+++ axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post.c Wed Jun  1 09:58:31 2011
@@ -130,7 +130,6 @@ main(
     /* un-comment line below to setup proxy from code*/
     /*axis2_svc_client_set_proxy_with_auth(svc_client, env, "127.0.0.1", "3128", NULL, NULL);*/
 
-    /* Sending robust authentication test message */
 
     /* Set http-auth information */
     if (un && pw)

Modified: axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post_with_check.c
URL: http://svn.apache.org/viewvc/axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post_with_check.c?rev=1130076&r1=1130075&r2=1130076&view=diff
==============================================================================
--- axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post_with_check.c (original)
+++ axis/axis2/c/core/trunk/samples/client/ntlm/ntlm_post_with_check.c Wed Jun  1 09:58:31 2011
@@ -49,7 +49,7 @@ main(
     /* Set up the environment */
     env = axutil_env_create_all("ntlm_auth_client_with_check.log", AXIS2_LOG_LEVEL_TRACE);
 
     /* Set end point reference of echo service */
     address = "http://172.16.176.132:80/myservice/Service1.asmx";
     if (argc > 1)
     {
@@ -221,7 +221,7 @@ main(
             om_str = axiom_node_to_string(ret_node, env);
             if (om_str)
                 printf("\nReceived OM : %s\n", om_str);
-            printf("\necho client invoke SUCCESSFUL!\n");
+            printf("\nntlm client invoke SUCCESSFUL!\n");
 
             AXIS2_FREE(env->allocator, om_str);
             ret_node = NULL;
@@ -232,7 +232,7 @@ main(
                             "Stub invoke FAILED: Error code:" " %d :: %s",
                             env->error->error_number,
                             AXIS2_ERROR_GET_MESSAGE(env->error));
-            printf("echo client invoke FAILED!\n");
+            printf("ntlm client invoke FAILED!\n");
         }
     }
     if (svc_client)
@@ -49,7 +49,7 @@ main(
     env = axutil_env_create_all("ntlm_auth_client_with_check.log", AXIS2_LOG_LEVEL_TRACE);
 
-    /* Set end point reference of echo service */
+    /* Set end point reference of ntlm service */
     address = "http://172.16.176.132:80/myservice/Service1.asmx";
     if (argc > 1)